<?php

namespace App\Http\Controllers\Users;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Microsoft\Graph\Graph;
use Microsoft\Graph\Model;
use Illuminate\Support\Facades\DB;

class UpdateUserController extends Controller
{
    public function updateUser(Request $request)
    {

        // Préparation email pro (mise en minuscule pour éviter les erreurs)
        // $emailPro = $request->all()['email_pro'];
        // $accentRemoverEmailPro = \Transliterator::create('NFD; [:Nonspacing Mark:] Remove; NFC')->transliterate($emailPro);
        // $emailPro = strtolower($accentRemoverEmailPro);

        // Préparation format numéro telPro
        $telPro = $request->all()['tel_pro'];
        $telPro = str_replace(' ', '', $telPro);
        $telPro = str_replace('.', '', $telPro);
        $telPro = str_replace('-', '', $telPro);
        if (preg_match('/^(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})$/', $telPro,  $matches)) {
            $telPro = $matches[1] . '.' . $matches[2] . '.' . $matches[3] . '.' . $matches[4] . '.' . $matches[5];
        }

        // Préparation format numéro telPerso
        $telPerso = $request->all()['tel_perso'];
        $telPerso = str_replace(' ', '', $telPerso);
        $telPerso = str_replace('.', '', $telPerso);
        $telPerso = str_replace('-', '', $telPerso);
        if (preg_match('/^(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})$/', $telPerso,  $matches)) {
            $telPerso = $matches[1] . '.' . $matches[2] . '.' . $matches[3] . '.' . $matches[4] . '.' . $matches[5];
        }

        try {
            DB::table('rh_employees')
                ->where('EMPLOYEE_ID', '=', $request->all()['user_id'])
                ->update([
                    'EMPLOYEE_COMPTEACTIF' => $request->all()['compte_actif'],
                    'EMPLOYEE_NOM' => strtoupper($request->all()['nom']),
                    'EMPLOYEE_PRENOM' => ucwords($request->all()['prenom']),
                    'EMPLOYEE_EMAILPRO' => strtolower($request->all()['email_pro']),
                    'EMPLOYEE_EMAILPERSO' => strtolower($request->all()['email_perso']),
                    'EMPLOYEE_TELPRO' => $telPro,
                    'EMPLOYEE_TELPERSO' => $telPerso,
                    'EMPLOYEE_ADRESSEPERSO' => $request->all()['adresse_perso'],
                    'EMPLOYEE_ADRESSEPERSOCOMPLEMENT' => $request->all()['adresse_perso_complement'],
                    'EMPLOYEE_CODEPOSTALPERSO' => $request->all()['codepostal_perso'],
                    'EMPLOYEE_VILLEPERSO' => $request->all()['ville_perso'],
                    'EMPLOYEE_STATUT' => $request->all()['statut'],
                    'EMPLOYEE_FONCTION' => $request->all()['fonction'],
                    'EMPLOYEE_SERVICE' => $request->all()['service'],
                    'EMPLOYEE_ESTCOURTIER' => $request->all()['est_courtier'],
                    'EMPLOYEE_FKAGENCEID' => $request->all()['fk_id_agence'],
                    'EMPLOYEE_TYPECONTRAT' => $request->all()['type_contrat'],
                    'EMPLOYEE_DATEARRIVEE' => $request->all()['date_entree'],
                    'EMPLOYEE_DATEDEPART' => $request->all()['date_depart'],
                    'EMPLOYEE_SIREN' => $request->all()['siren'],
                ]);

            // Recherche des agences pour récupérer informations avant mise à jour Azure AD
            $agence = DB::table('rh_agences')
                ->where('AGENCE_ID', '=', $request->all()['fk_id_agence'])
                ->get();

            // Préparation des variables pour mise à jour Azure AD
            $accentRemoverPrenom = \Transliterator::create('NFD; [:Nonspacing Mark:] Remove; NFC')->transliterate($request->all()['prenom']);
            $accentRemoverNom = \Transliterator::create('NFD; [:Nonspacing Mark:] Remove; NFC')->transliterate($request->all()['nom']);
            $mailNickname = strtolower($accentRemoverPrenom . "." . $accentRemoverNom);
            $givenName = ucwords($request->all()['prenom']);
            $surname = ucwords(strtolower($request->all()['nom']));
            $emailPro = strtolower($request->all()['email_pro']);
            $jobTitle = ucwords(strtolower($request->all()['fonction']));
            if ($agence[0]->AGENCE_ADRESSECOMPLEMENT != '' || $agence[0]->AGENCE_ADRESSECOMPLEMENT !== null) {
                $streetAdress = $agence[0]->AGENCE_ADRESSE . " - " . $agence[0]->AGENCE_ADRESSECOMPLEMENT;
            } else {
                $streetAdress = $agence[0]->AGENCE_ADRESSE;
            }

            // Pour eviter les erreur Azure AD
            if ($telPro == '') {
                $telPro = '00.00.00.00.00';
            }
            if ($telPerso == '') {
                $telPerso = '00.00.00.00.00';
            }

            // Preparation de la requête pour mise à jour Azure AD
            $userPayload = array(
                "accountEnabled" => false,
                "displayName" => $givenName . " " . $surname,
                "mailNickname" => $mailNickname,
                "givenName" => $givenName,
                "surname" => $surname,
                "userPrincipalName" => $emailPro,
                "jobTitle" => $jobTitle,
                "officeLocation" => $agence[0]->AGENCE_NOM,
                "department" => $request->all()['service'],
                "businessPhones" => [
                    $telPro
                ],
                "mobilePhone" => "$telPerso",
                "streetAddress" => $streetAdress,
                "postalCode" => $agence[0]->AGENCE_CODEPOSTAL,
                "city" => $agence[0]->AGENCE_VILLE,
                "country" => 'France',
                "preferredLanguage" => "fr-FR",
                "passwordProfile" => [
                    "forceChangePasswordNextSignIn" => false,
                    "password" => "IccFinance31!"
                ],
            );

            // Exécution de la requêt pour mise à jour Azure AD
            $graph = new Graph();

            $graph->setAccessToken(session('accessToken'));

            $graph->createRequest('PATCH', '/users/'.strtolower($request->all()['email_pro']))
                ->setReturnType(Model\User::class)
                ->attachBody($userPayload)
                ->execute();

        } catch (\Exception $e) {
            // Ignorer l'erreur
        }

        return back()->withInput();
    }
}
